@@ -15,159 +15,24 @@
 """
 Decorators.
 
-Mainly do two things. Ensure API guidelines are met and prevent unneccesary
+Mainly do two things. Ensure API guidelines are met and prevent unnecessary
 failed API requests by testing that the call can be made first. Also limit the
 length of output strings and parse json response for certain errors.
 """
 
+import os
 import six
 import sys
-import time
 from functools import wraps
 from requests.compat import urljoin
-
 from praw import errors
 
 
-class Memoize(object):
-
-    """Memoize decorator with timeout to clear cache of timed out results."""
-
-    @staticmethod
-    def normalize_url(url):
-        """Return url after stripping trailing .json and trailing slashes."""
-        if url.endswith('.json'):
-            url = url[:-5]
-        if url.endswith('/'):
-            url = url[:-1]
-        return url
-
-    def __init__(self, function):
-        wraps(function)(self)
-        self.function = function
-        self._cache = {}
-        self._timeouts = {}
-
-    def __call__(self, reddit_session, url, *args, **kwargs):
-        # Ignore uploads
-        if kwargs.get('files'):
-            return self.function(reddit_session, url, *args, **kwargs)
-
-        normalized_url = self.normalize_url(url)
-        key = (reddit_session, normalized_url, repr(args),
-               frozenset(six.iteritems(kwargs)))
-        call_time = time.time()
-        self.clear_timeouts(call_time, reddit_session.config.cache_timeout)
-        self._timeouts.setdefault(key, call_time)
-        if key in self._cache:
-            return self._cache[key]
-        result = self.function(reddit_session, url, *args, **kwargs)
-        if kwargs.get('raw_response'):
-            return result
-        return self._cache.setdefault(key, result)
-
-    def clear_timeouts(self, call_time, cache_timeout):
-        """Clear the cache of timed out results."""
-        for key in list(self._timeouts):
-            if call_time - self._timeouts[key] > cache_timeout:
-                del self._timeouts[key]
-                if key in self._cache:
-                    del self._cache[key]
-
-    def empty(self):
-        """Empty the entire cache."""
-        self._cache = {}
-        self._timeouts = {}
-
-    def evict(self, urls):
-        """Remove cached RedditContentObject by URL."""
-        urls = [self.normalize_url(url) for url in urls]
-        relevant_caches = [key for key in self._cache if key[1] in urls]
-        for key in relevant_caches:
-            del self._cache[key]
-            del self._timeouts[key]
+# Don't decorate functions when building the documentation
+IS_SPHINX_BUILD = bool(os.getenv('SPHINX_BUILD'))
 
 
-class RequireCaptcha(object):
-
-    """Decorator for methods that require captchas."""
-
-    @staticmethod
-    def get_captcha(reddit_session, captcha_id):
-        """Prompt user for captcha solution and return a prepared result."""
-        url = urljoin(reddit_session.config['captcha'],
-                      captcha_id + '.png')
-        sys.stdout.write('Captcha URL: %s\nCaptcha: ' % url)
-        sys.stdout.flush()
-        captcha = sys.stdin.readline().strip()
-        return {'iden': captcha_id, 'captcha': captcha}
-
-    def __init__(self, function):
-        wraps(function)(self)
-        self.function = function
-
-    def __get__(self, obj, key):
-        if obj is None:
-            return self
-        return self.__class__(self.function.__get__(obj, key))
-
-    def __call__(self, *args, **kwargs):
-        if 'raise_captcha_exception' in kwargs:
-            raise_captcha_exception = kwargs['raise_captcha_exception']
-            del kwargs['raise_captcha_exception']
-        else:
-            raise_captcha_exception = False
-        captcha_id = None
-        while True:
-            try:
-                if captcha_id:
-                    # Differentiate between bound and unbound methods
-                    if hasattr(self.function, '__self__'):
-                        reddit_session = self.function.__self__
-                    else:
-                        reddit_session = args[0]
-                    kwargs['captcha'] = self.get_captcha(reddit_session,
-                                                         captcha_id)
-                return self.function(*args, **kwargs)
-            except errors.InvalidCaptcha as exception:
-                if raise_captcha_exception:
-                    raise
-                captcha_id = exception.response['captcha']
-
-
-class SleepAfter(object):  # pylint: disable-msg=R0903
-
-    """Ensure frequency of API calls doesn't exceed guidelines.
-
-    We are allowed to make a API request every api_request_delay seconds as
-    specified in praw.ini. This value may differ from reddit to reddit. For
-    reddit.com it is 2. Any function decorated with this will be forced to
-    delay api_request_delay seconds from the calling of the last function
-    decorated with this before executing.
-
-    """
-
-    def __init__(self, function):
-        wraps(function)(self)
-        self.function = function
-        self.last_call = {}
-
-    def __call__(self, *args, **kwargs):
-        config = args[0].config
-        if config.domain in self.last_call:
-            last_call = self.last_call[config.domain]
-        else:
-            last_call = 0
-        now = time.time()
-        delay = last_call + int(config.api_request_delay) - now
-        if delay > 0:
-            now += delay
-            time.sleep(delay)
-        self.last_call[config.domain] = now
-        return self.function(*args, **kwargs)
-
-
-def alias_function(function):
+def alias_function(function, class_name):
     """Create a RedditContentObject function mapped to a BaseReddit function.
 
     The BaseReddit classes define the majority of the API's functions. The
@@ -179,19 +44,26 @@ def alias_function(function):
     @wraps(function)
     def wrapped(self, *args, **kwargs):
         return function(self.reddit_session, self, *args, **kwargs)
+    # Only grab the short-line doc and add a link to the complete doc
+    wrapped.__doc__ = wrapped.__doc__.split('\n', 1)[0]
+    wrapped.__doc__ += ('\n\nSee :meth:`.{0}.{1}` for complete usage. '
+                        'Note that you should exclude the first parameter '
+                        'when calling this convenience method.'
+                        .format(class_name, function.__name__))
+    # Don't hide from sphinx as this is a parameter modifying decorator
     return wrapped
 
 
 def limit_chars(function):
     """Truncate the string returned from a function and return the result."""
     @wraps(function)
-    def function_wrapper(self, *args, **kwargs):
+    def wrapped(self, *args, **kwargs):
         output_chars_limit = self.reddit_session.config.output_chars_limit
         output_string = function(self, *args, **kwargs)
         if -1 < output_chars_limit < len(output_string):
             output_string = output_string[:output_chars_limit - 3] + '...'
         return output_string
-    return function_wrapper
+    return function if IS_SPHINX_BUILD else wrapped
 
 
 def oauth_generator(function):
@@ -209,18 +81,18 @@ def oauth_generator(function):
         if getattr(reddit_session, '_use_oauth', False):
             kwargs['_use_oauth'] = True
         return function(reddit_session, *args, **kwargs)
-    return wrapped
+    return function if IS_SPHINX_BUILD else wrapped
 
 
-def parse_api_json_response(function):  # pylint: disable-msg=R0912
-    """Raise client side exception(s) when presenet in the API response.
+def raise_api_exceptions(function):
+    """Raise client side exception(s) when present in the API response.
 
     Returned data is not modified.
 
     """
     @wraps(function)
-    def error_checked_function(cls, *args, **kwargs):
-        return_value = function(cls, *args, **kwargs)
+    def wrapped(reddit_session, *args, **kwargs):
+        return_value = function(reddit_session, *args, **kwargs)
         if isinstance(return_value, dict):
             if return_value.get('error') == 304:  # Not modified exception
                 raise errors.NotModified(return_value)
@@ -229,7 +101,7 @@ def parse_api_json_response(function):  # pylint: disable-msg=R0912
                 for error_type, msg, value in return_value['errors']:
                     if error_type in errors.ERROR_MAPPING:
                         if error_type == 'RATELIMIT':
-                            _request.evict(args[0])
+                            reddit_session.evict(args[0])
                         error_class = errors.ERROR_MAPPING[error_type]
                     else:
                         error_class = errors.APIException
@@ -240,7 +112,55 @@ def parse_api_json_response(function):  # pylint: disable-msg=R0912
                 else:
                     raise errors.ExceptionList(error_list)
         return return_value
-    return error_checked_function
+    return function if IS_SPHINX_BUILD else wrapped
+
+
+def require_captcha(function):
+    """Return a decorator for methods that require captchas."""
+    def get_captcha(reddit_session, captcha_id):
+        """Prompt user for captcha solution and return a prepared result."""
+        url = urljoin(reddit_session.config['captcha'],
+                      captcha_id + '.png')
+        sys.stdout.write('Captcha URL: %s\nCaptcha: ' % url)
+        sys.stdout.flush()
+        raw = sys.stdin.readline()
+        if not raw:  # stdin has reached the end of file
+            # Trigger exception raising next time through. The request is
+            # cached so this will not require and extra request and delay.
+            sys.stdin.close()
+            return None
+        return {'iden': captcha_id, 'captcha': raw.strip()}
+
+    function.__doc__ += ('\nThis function may result in a captcha challenge. '
+                         'PRAW will automatically prompt you for a response. '
+                         'See :ref:`handling-captchas` if you want to manually'
+                         ' handle captchas.')
+
+    @wraps(function)
+    def wrapped(obj, *args, **kwargs):
+        if 'raise_captcha_exception' in kwargs:
+            raise_captcha_exception = kwargs['raise_captcha_exception']
+            del kwargs['raise_captcha_exception']
+        else:
+            raise_captcha_exception = False
+        captcha_id = None
+
+        # Get a handle to the reddit session
+        if hasattr(obj, 'reddit_session'):
+            reddit_session = obj.reddit_session
+        else:
+            reddit_session = obj
+
+        while True:
+            try:
+                if captcha_id:
+                    kwargs['captcha'] = get_captcha(reddit_session, captcha_id)
+                return function(obj, *args, **kwargs)
+            except errors.InvalidCaptcha as exception:
+                if sys.stdin.closed or raise_captcha_exception:
+                    raise
+                captcha_id = exception.response['captcha']
+    return function if IS_SPHINX_BUILD else wrapped
 
 
 def restrict_access(scope, mod=False, login=False, oauth_only=False):
@@ -267,7 +187,7 @@ def restrict_access(scope, mod=False, login=False, oauth_only=False):
     This decorator assumes that all mod required functions fit one of:
 
       * have the subreddit as the first argument (Reddit instance functions)
-      * are called upon a subreddit object (Subredit RedditContentObject)
+      * are called upon a subreddit object (Subreddit RedditContentObject)
       * are called upon a RedditContent object with attribute subreddit
 
     """
@@ -341,7 +261,7 @@ def restrict_access(scope, mod=False, login=False, oauth_only=False):
                 return function(cls, *args, **kwargs)
             finally:
                 obj._use_oauth = False  # pylint: disable-msg=W0212
-        return wrapped
+        return function if IS_SPHINX_BUILD else wrapped
     return wrap
 
 
@@ -352,15 +272,11 @@ def require_oauth(function):
 
     """
     @wraps(function)
-    def validate_function(self, *args, **kwargs):
+    def wrapped(self, *args, **kwargs):
         if not self.has_oauth_app_info:
             err_msg = ("The OAuth app config parameters client_id, "
                        "client_secret and redirect_url must be specified to "
                        "use this function.")
             raise errors.OAuthAppRequired(err_msg)
         return function(self, *args, **kwargs)
-    return validate_function
-
-
-# Avoid circular import: http://effbot.org/zone/import-confusion.htm
-from .helpers import _request
+    return function if IS_SPHINX_BUILD else wrapped
