@@ -28,7 +28,7 @@ import unittest
 import uuid
 from functools import wraps
 from requests.compat import urljoin
-from requests.exceptions import HTTPError, Timeout
+from requests.exceptions import HTTPError
 from six import advance_iterator as six_next, text_type
 
 from praw import Reddit, decorators, errors, helpers
@@ -99,28 +99,29 @@ class BasicHelper(object):
         self.invalid_user_name = 'PyAPITestInvalid'
 
         if self.r.config.is_reddit:
-            self.comment_url = self.url('r/redditdev/comments/dtg4j/')
+            self.comment_url = self.url('/r/redditdev/comments/dtg4j/')
             self.link_url = self.url('/r/UCSantaBarbara/comments/m77nc/')
             self.link_url_link = 'http://imgur.com/Vr8ZZ'
             self.more_comments_url = self.url('/r/redditdev/comments/dqkfz/')
             self.other_user_id = '6c1xj'
             self.priv_submission_id = '16kbb7'
             self.refresh_token = {
-                'edit':            'mFB93g1nlgt57gd2ch9xy8815ng',
-                'identity':        'pwKb6vuFpbqTQjLPTBK_4LW0x3U',
-                'modconfig':       'm8em73vTHVaA05_DX-m0RHVBXdU',
-                'modflair':        'Zt7sl88AKsljl7VS19gifVHNBaU',
-                'modlog':          'Ql-qe7ad56-5UsIP4GN14__t_aY',
-                'modposts':        'fdbclNlJorCA_GcD42JLxhNM6mc',
-                'mysubreddits':    'HCnSeHp9Rw3fdMd9SkEOdNuys2c',
-                'privatemessages': 'pu7vyu-RtB5Z2LkmHJnwKxoStqw',
-                'read':            'qa43Mc1v9RjsJCm_tjEUFrN27IU',
-                'submit':          'DSJdhcEd9vkwHWqRenDiY042iW0',
-                'subscribe':       '8xgyDmQm9FOfOmKnhGcA2bvfywg',
-                'vote':            'odS8Wkmgt_kgnUiYfvK6v4u1sAQ'}
+                'edit':            'FFx_0G7Zumyh4AWzIo39bG9KdIM',
+                'identity':        'E4BgmO7iho0KOB1XlT8WEtyySf8',
+                'modconfig':       'bBGRgMY9Ai9_SZLZsaFvS647Mgk',
+                'modflair':        'UrMbtk4bOa040XAVz0uQn2gTE3s',
+                'modlog':          'ADW_EDS9-bh7Zicc7ARx7w8ZLMA',
+                'modposts':        'Ffnae7s4K-uXYZB5ZaYJgh0d8DI',
+                'mysubreddits':    'O7tfWhqem6fQZqxhoTiLca1s7VA',
+                'privatemessages': 'kr_pHPO3sqTn_m5f_FX9TW4joEU',
+                'read':            '_mmtb8YjDym0eC26G-rTxXUMea0',
+                'submit':          'k69WTwa2bEQOQY9t61nItd4twhw',
+                'subscribe':       'LlqwOLjyu_l6GMZIBqhcLWB0hAE',
+                'vote':            '5RPnDwg56vAbf7F9yO81cXZAPSQ'}
             self.submission_edit_id = '16i92b'
         else:
-            self.comment_url = self.url('/r/reddit_test6/comments/y/')
+            self.comment_url = self.url(
+                '/r/reddit_api_test/comments/iq/_/3a7/')
             self.link_url = self.url('/r/reddit_test6/comments/y/')
             self.link_url_link = 'http://google.com/?q=29.9093488449'
             self.more_comments_url = self.url('/r/reddit_test6/comments/y/')
@@ -177,21 +178,21 @@ class AccessControlTests(unittest.TestCase, BasicHelper):
         self.r.set_access_credentials(set('dummy_scope',), 'dummy_token')
         self.assertRaises(errors.OAuthScopeRequired, self.r.get_me)
 
-    def test_moderator_or_oauth_required_loged_in_from_reddit_obj(self):
+    def test_moderator_or_oauth_required_logged_in_from_reddit_obj(self):
         oth = Reddit(USER_AGENT, disable_update_check=True)
-        oth.login('PyAPITestUser3', '1111')
+        oth.login('PyAPITestUser4', '1111')
         self.assertRaises(errors.ModeratorOrScopeRequired,
                           oth.get_settings, self.sr)
 
-    def test_moderator_or_oauth_required_loged_in_from_submission_obj(self):
+    def test_moderator_or_oauth_required_logged_in_from_submission_obj(self):
         oth = Reddit(USER_AGENT, disable_update_check=True)
-        oth.login('PyAPITestUser3', '1111')
+        oth.login('PyAPITestUser4', '1111')
         submission = oth.get_submission(url=self.comment_url)
         self.assertRaises(errors.ModeratorOrScopeRequired, submission.remove)
 
-    def test_moderator_or_oauth_required_loged_in_from_subreddit_obj(self):
+    def test_moderator_or_oauth_required_logged_in_from_subreddit_obj(self):
         oth = Reddit(USER_AGENT, disable_update_check=True)
-        oth.login('PyAPITestUser3', '1111')
+        oth.login('PyAPITestUser4', '1111')
         subreddit = oth.get_subreddit(self.sr)
         self.assertRaises(errors.ModeratorOrScopeRequired,
                           subreddit.get_settings)
@@ -330,10 +331,10 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def test_search_reddit_names(self):
         self.assertTrue(len(self.r.search_reddit_names('reddit')) > 0)
 
-    def test_timeout(self):
+    #def test_timeout(self):
         # pylint: disable-msg=W0212
-        self.assertRaises(Timeout, helpers._request, self.r,
-                          self.r.config['comments'], timeout=0.001)
+    #    self.assertRaises(Timeout, helpers._request, self.r,
+    #                      self.r.config['comments'], timeout=0.001)
 
 
 class CacheTest(unittest.TestCase, AuthenticatedHelper):
@@ -1237,7 +1238,7 @@ class SettingsTest(unittest.TestCase, AuthenticatedHelper):
 
     def test_set_settings(self):
         title = 'Reddit API Test %s' % uuid.uuid4()
-        self.subreddit.set_settings(title)
+        self.subreddit.set_settings(title, wikimode='anyone')
         self.assertEqual(self.subreddit.get_settings()['title'], title)
 
     def test_set_stylesheet(self):
